#' get_short_e1a_data

#' get_short_e1a_data
#' @param eeaObj eeaObj
#' @param Pollutant Pollutant
#' @param From From date
#' @param To To date
#' @param Resolution timeResolution
#' @param StationEoi StationEoi
#' @keywords eea.nilu
#' @export
get_short_e1a_data <- function(eeaObj,Pollutant,From,To,Resolution,StationEoi) {

  res <- short_e1a_data_init()

  for (i in 1:length(Pollutant)){
    for (j in 1:length(StationEoi)){
      tmp <- eeaObj$e1a(Pollutant=Pollutant[i],
                        From=From,
                        To=To,
                        Resolution=Resolution,
                        StationEoi=StationEoi[j])

      if(!is.null(tmp)) {
        nrows <- length(tmp)
        for ( k in 1:nrows) {
          df <- build_e1a_data_df(tmp=tmp,indice=k)
          res <- rbind(res,df)
        }
      }
    }
  }

  return(res)
}


build_e1a_data_df <- function(tmp,indice){
  res <- short_e1a_data_df(tmp=tmp,indice=indice)
  return(res)
}


short_e1a_data_init <- function(){
  df <- data.frame(from  = character(0),
                   to  = character(0),
                   ID  = character(0),
                   CO_NAME  = character(0),
                   value = numeric(0),
                   unit = character(0),
                   timeResolution = character(0),
                   validity = numeric(0),
                   verification = numeric(0),
                   samplingPoint = character(0)
                 )
  return(df)
}


short_e1a_data_df <- function(tmp,indice){

  df <- data.frame(from  = ifelse(is.null(tmp[[indice]]$fromTime),NA,tmp[[indice]]$fromTime),
                   to  = ifelse(is.null(tmp[[indice]]$toTime),NA,tmp[[indice]]$toTime),
                   ID  = ifelse(is.null(tmp[[indice]]$stationEoi),NA,tmp[[indice]]$stationEoi),
                   CO_NAME  = ifelse(is.null(tmp[[indice]]$pollutant),NA,tmp[[indice]]$pollutant),
                   value = ifelse(is.null(tmp[[indice]]$value),NA,tmp[[indice]]$value),
                   unit = ifelse(is.null(tmp[[indice]]$unit),NA,tmp[[indice]]$unit),
                   timeResolution = ifelse(is.null(tmp[[indice]]$resolution),NA,tmp[[indice]]$resolution),
                   validity = ifelse(is.null(tmp[[indice]]$validity),NA,tmp[[indice]]$validity),
                   verification = ifelse(is.null(tmp[[indice]]$verification),NA,tmp[[indice]]$verification),
                   samplingPoint = ifelse(is.null(tmp[[indice]]$samplingPoint),NA,tmp[[indice]]$samplingPoint))
  return(df)
}

#' get_short_e2a_data

#' get_short_e2a_data
#' @param eeaObj eeaObj
#' @param Pollutant Pollutant
#' @param HoursBack HoursBack
#' @param Country Country
#' @param Resolution timeResolution
#' @param StationEoi StationEoi
#' @param SamplingPoint SamplingPoint
#' @keywords eea.nilu
#' @export
get_short_e2a_data <- function(eeaObj,Pollutant,HoursBack,Country=NULL,Resolution,StationEoi,SamplingPoint=NULL) {

  res <- short_e2a_data_init()

  for (i in 1:length(Pollutant)){
    for (j in 1:length(StationEoi)){
      tmp <- eeaObj$e2a(Pollutant=Pollutant[i],
                        HoursBack=HoursBack,
                        Country=Country,
                        Resolution=Resolution,
                        StationEoi=StationEoi[j],
                        SamplingPoint = SamplingPoint)

      if(!is.null(tmp)) {
        nrows <- length(tmp)
        for ( k in 1:nrows) {
          df <- build_e2a_data_df(tmp=tmp,indice=k)
          res <- rbind(res,df)
        }
      }
    }
  }

  return(res)
}


build_e2a_data_df <- function(tmp,indice){
  res <- short_e2a_data_df(tmp=tmp,indice=indice)
  return(res)
}


short_e2a_data_init <- function(){
  df <- data.frame(from  = character(0),
                   to  = character(0),
                   ID  = character(0),
                   CO_NAME  = character(0),
                   value = numeric(0),
                   unit = character(0),
                   timeResolution = character(0),
                   validity = numeric(0),
                   verification = numeric(0),
                   samplingPoint = character(0)
                 )
  return(df)
}


short_e2a_data_df <- function(tmp,indice){

  df <- data.frame(from  = ifelse(is.null(tmp[[indice]]$fromTime),NA,tmp[[indice]]$fromTime),
                   to  = ifelse(is.null(tmp[[indice]]$toTime),NA,tmp[[indice]]$toTime),
                   ID  = ifelse(is.null(tmp[[indice]]$stationEoi),NA,tmp[[indice]]$stationEoi),
                   CO_NAME  = ifelse(is.null(tmp[[indice]]$pollutant),NA,tmp[[indice]]$pollutant),
                   value = ifelse(is.null(tmp[[indice]]$value),NA,tmp[[indice]]$value),
                   unit = ifelse(is.null(tmp[[indice]]$unit),NA,tmp[[indice]]$unit),
                   timeResolution = ifelse(is.null(tmp[[indice]]$resolution),NA,tmp[[indice]]$resolution),
                   validity = ifelse(is.null(tmp[[indice]]$validity),NA,tmp[[indice]]$validity),
                   verification = ifelse(is.null(tmp[[indice]]$verification),NA,tmp[[indice]]$verification),
                   samplingPoint = ifelse(is.null(tmp[[indice]]$samplingPoint),NA,tmp[[indice]]$samplingPoint))
  return(df)
}
