
#' get_short_metadata_data

#' get_short_metadata_data
#' @param eeaObj eeaObj
#' @param StationEoi station ids
#' @param west west
#' @param south south
#' @param east east
#' @param north north
#' @keywords eea.nilu
#' @export
get_short_metadata_data <- function(eeaObj,StationEoi=NULL,west=NULL,south=NULL,east=NULL,north=NULL) {

   res <- short_meta_data_init()

    if (!is.null(StationEoi)) {
      for ( i in 1:length(StationEoi)) {
        tmp <- eeaObj$metadata(StationEoi=StationEoi[i])
        if(!is.null(tmp)) {
          df <- short_meta_data_df(tmp=tmp,indice=1)
          res <- rbind(res,df)
        }
      }
    }  else if ((!is.null(west)) && (!is.null(south)) && (!is.null(east)) && (!is.null(north))){
      bbox <- glue::glue('{west},{south},{east},{north}')
      tmp <- eeaObj$metadata(BBox=bbox)
      if(!is.null(tmp)) {
        nrows <- length(tmp)
        for ( k in 1:nrows) {
          df <- short_meta_data_df(tmp=tmp,indice=k)
          res <- rbind(res,df)
        }
      }
  }

  return(res)

}


build_meta_data_df <- function(tmp,indice){
  res <- short_meta_data_df(tmp=tmp,indice=indice)
  return(res)
}


short_meta_data_init <- function(){
  df <- data.frame(namespace  = character(0),
                   country  = character(0),
                   network  = character(0),
                   station  = character(0),
                   stationEoi = character(0),
                   latitude = character(0),
                   longitude = character(0),
                   projection  = character(0),
                   samplingPoint = character(0),
                   stationType  = character(0),
                   stationArea  = character(0),
                   fromTime  = character(0),
                   toTime  = character(0),
                   timezone = character(0)
                 )
  return(df)
}


short_meta_data_df <- function(tmp,indice){
  df <- data.frame(namespace  = ifelse(is.null(tmp[[indice]]$namespace),NA,tmp[[indice]]$namespace),
                   country  = ifelse(is.null(tmp[[indice]]$country),NA,tmp[[indice]]$country),
                   network  = ifelse(is.null(tmp[[indice]]$network),NA,tmp[[indice]]$network),
                   station  = ifelse(is.null(tmp[[indice]]$station),NA,tmp[[indice]]$station),
                   stationEoi = ifelse(is.null(tmp[[indice]]$stationEoi),NA,tmp[[indice]]$stationEoi),
                   latitude = ifelse(is.null(tmp[[indice]]$latitude),NA,tmp[[indice]]$latitude),
                   longitude = ifelse(is.null(tmp[[indice]]$longitude),NA,tmp[[indice]]$longitude),
                   projection  = ifelse(is.null(tmp[[indice]]$projection),NA,tmp[[indice]]$projection),
                   samplingPoint = ifelse(is.null(tmp[[indice]]$samplingPoint),NA,tmp[[indice]]$samplingPoint),
                   stationType  = ifelse(is.null(tmp[[indice]]$stationType),NA,tmp[[indice]]$stationType),
                   stationArea  = ifelse(is.null(tmp[[indice]]$stationArea),NA,tmp[[indice]]$stationArea),
                   fromTime  = ifelse(is.null(tmp[[indice]]$fromTime),NA,tmp[[indice]]$fromTime),
                   toTime  = ifelse(is.null(tmp[[indice]]$toTime),NA,tmp[[indice]]$toTime),
                   timezone  = ifelse(is.null(tmp[[indice]]$timezone),NA,tmp[[indice]]$timezone)
                 )
  return(df)
}
